%This script will model the condenser using collocation

clear all
n=3; %For cooling
m=25; %For integral condensation
[xn, An, Bn, qn] = colloc( n ,1 ,1);
[xm, Am, Bm, qm] = colloc( m ,1 ,1);
Ao=Am;
o=m;
xo=xm;

constant

%The starting values are from table 5.1 in previous master thesis

T0= 31.2 + 273; % K
P0= 20.740*10^5; % Pa
Ta0=6.5 + 273;% K
L0=0; % Liquid molar flow [mol vapour/s]
Vm0=478.31; %vapour mass flow [kg/s]
yeth0=0.64;%;
yprop0=0.36;%;
u0=0.61;    %velocity [m/s]

M0=yeth0*Meth+Mprop*yprop0; %Calculate the molar mass of vapour feed
V0=Vm0/M0; %Calculate vapour molar flow [kmol/s]

ntot=V0;
Nev0=yeth0*V0;
Npv0=yprop0*V0;
Nel0=0.41;
Npl0=0.59;

Tdew=dewpoint(yeth0);

 load y_0405_cond6_2

t=(n+2)*3+(m+2)*7; 
t1=n+2;
t2=m+2;


% % 
% y=ones(t+1,1);
% y(1:t1)=T0.*y(1:t1);
% y(t1+1:2*t1)=P0.*y(t1+1:2*t1);
% y(2*t1+1:3*t1)=Ta0.*y(2*t1+1:3*t1);
% % y(3*t1+1:4*t1)=u0.*y(3*t1+1:4*t1);
% 
% 
% y(3*t1+1:3*t1+t2)=Tdew.*y(3*t1+1:3*t1+t2);
% y(3*t1+t2+1:3*t1+2*t2)=P0.*y(3*t1+t2+1:3*t1+2*t2);
% y(3*t1+2*t2+1:3*t1+3*t2)=Ta0.*y(3*t1+2*t2+1:3*t1+3*t2);
% y(3*t1+3*t2+1:3*t1+4*t2)=Nev0.*y(3*t1+3*t2+1:3*t1+4*t2);
% y(3*t1+4*t2+1:3*t1+5*t2)=Npv0.*y(3*t1+4*t2+1:3*t1+5*t2);
% % 
% % % y(4*t1+1:4*t1+t2)=Tdew.*y(4*t1+1:4*t1+t2);
% % % y(4*t1+t2+1:4*t1+2*t2)=P0.*y(4*t1+t2+1:4*t1+2*t2);
% % % y(4*t1+2*t2+1:4*t1+3*t2)=Ta0.*y(4*t1+2*t2+1:4*t1+3*t2);
% % % y(4*t1+3*t2+1:4*t1+4*t2)=Nev0.*y(4*t1+3*t2+1:4*t1+4*t2);
% % % y(4*t1+4*t2+1:4*t1+5*t2)=Npv0.*y(4*t1+4*t2+1:4*t1+5*t2);
% % % % y(4*t1+7*t2+1:4*t1+8*t2)=u0.*y(4*t1+7*t2+1:4*t1+8*t2);
% y(t+1)=500;
% y(t+2)=10000;
% y(t+3)=1.8;




y0=[T0 P0 Ta0 u0];


opt=optimset('Display','iter','MaxFunEvals',50000,'MaxIter',100000,'TolX',1E-10);
y=fsolve(@(y) condensermodell6(y,An,n,xn,Am,m,xm,Ao,o,xo,Tdew,y0,Nel0,Npl0,Nev0,Npv0),y,opt);

T(1:t1)=y(1:t1);
T(t1+1:t1+t2)=y(3*t1+1:3*t1+t2);
T=T';
P(1:t1)=y(t1+1:2*t1);
P(t1+1:t1+t2)=y(3*t1+t2+1:3*t1+2*t2);
P=P';
Ta(1:t1)=y(2*t1+1:3*t1);
Ta(t1+1:t1+t2)=y(3*t1+2*t2+1:3*t1+3*t2);
Ta=Ta';
Nev(1:t1)=Nev0.*ones(1,n+2);
Nev(t1+1:t1+t2)=y(3*t1+3*t2+1:3*t1+4*t2);
Nev=Nev';
Npv(1:t1)=Npv0.*ones(1,n+2);
Npv(t1+1:t1+t2)=y(3*t1+4*t2+1:3*t1+5*t2);
Npv=Npv';

Nev0v=Nev0*ones(1,m+2+n+2)';
Nel0v=Nel0*ones(1,m+2+n+2)';
Npv0v=Npv0*ones(1,m+2+n+2)';
Npl0v=Npl0*ones(1,m+2+n+2)';

Nel=Nev0v-Nev;
Npl=Npv0v-Npv;

nt(1:t1)=zeros(1,t1);
nt(t1+1:t1+t2)=y(3*t1+5*t2+1:3*t1+6*t2);
nt=nt';
ne(1:t1)=zeros(1,t1);
ne(t1+1:t1+t2)=y(3*t1+6*t2+1:3*t1+7*t2);
ne=ne';

np=nt-ne;

% A1=300;
% A2=3000;
A1=y(t+1);
A2=y(t+2);
xt(1:t1)=A1.*xn;
xt(t1+1:t1+t2)=A1+A2.*xm;

save condensation_0206_condmod6_1

figure(1)
plot(xt,T,xt,Ta)
title('Temperature, hg=100,U=1000, A2=10000')

figure(2)
plot(xt,Nev,xt,Npv,xt,Nel,xt,Npl)
title('Composition profile along condenser')
legend('Ethane vapour','Propane vapour','Ethane liquid','Propane liquid',-1);