%This script will model the condenser using collocation

clear all
%Decide internal collocation points
n=3; %For cooling
m=25; %For integral condensation
o=10; %For differential condensation
[xn, An, Bn, qn] = colloc( n ,1 ,1);
[xm, Am, Bm, qm] = colloc( m ,1 ,1);
[xo, Ao, Bo, qo] = colloc( o ,1 ,1);

%Import constants
constant

%The starting values are from table 5.1 in \cite{master09}

T0= 31.2 + 273; % K
P0= 20.740*10^5; % Pa
Ta0=6.5 + 273;% K
L0=0; % Liquid molar flow [mol vapour/s]
Vm0=478.31; %vapour mass flow [kg/s]
yeth0=0.64;
yprop0=0.36;
u0=0.61;    %velocity [m/s]

M0=yeth0*Meth+Mprop*yprop0; %Calculate the molar mass of vapour feed
V0=Vm0/M0; %Calculate vapour molar flow [kmol/s]

ntot=V0;
Nev0=yeth0*V0;
Npv0=yprop0*V0;
Nel0=0.00041;
Npl0=0.000595;

%Calculate dewpoint
Tdew=dewpoint(yeth0);

%load guess values for collocation points
load y_0305_cond3_1;



t=(n+2)*3+(m+2)*7+(o+2)*7;

t1=n+2;
t2=m+2;
t3=o+2;

%guess values for collocation points if good guess values were not
%available

% y=ones(t+2,1);
% 
% y(1:t1)=T0.*y(1:t1);
% y(t1+1:2*t1)=P0.*y(t1+1:2*t1);
% y(2*t1+1:3*t1)=Ta0.*y(2*t1+1:3*t1);
% % y(3*t1+1:4*t1)=u0.*y(3*t1+1:4*t1);
% 
% 
% y(3*t1+1:3*t1+t2)=Tdew.*y(3*t1+1:3*t1+t2);
% y(3*t1+t2+1:3*t1+2*t2)=P0.*y(3*t1+t2+1:3*t1+2*t2);
% y(3*t1+2*t2+1:3*t1+3*t2)=Ta0.*y(3*t1+2*t2+1:3*t1+3*t2);
% y(3*t1+3*t2+1:3*t1+4*t2)=Nev0.*y(3*t1+3*t2+1:3*t1+4*t2);
% y(3*t1+4*t2+1:3*t1+5*t2)=Npv0.*y(3*t1+4*t2+1:3*t1+5*t2);
% 
% % y(4*t1+1:4*t1+t2)=Tdew.*y(4*t1+1:4*t1+t2);
% % y(4*t1+t2+1:4*t1+2*t2)=P0.*y(4*t1+t2+1:4*t1+2*t2);
% % y(4*t1+2*t2+1:4*t1+3*t2)=Ta0.*y(4*t1+2*t2+1:4*t1+3*t2);
% % y(4*t1+3*t2+1:4*t1+4*t2)=Nev0.*y(4*t1+3*t2+1:4*t1+4*t2);
% % y(4*t1+4*t2+1:4*t1+5*t2)=Npv0.*y(4*t1+4*t2+1:4*t1+5*t2);
% % y(4*t1+7*t2+1:4*t1+8*t2)=u0.*y(4*t1+7*t2+1:4*t1+8*t2);
% % y(end)=715;
% 
% y(3*t1+7*t2+1:3*t1+7*t2+t3)=Tdew.*y(3*t1+7*t2+1:3*t1+7*t2+t3);
% y(3*t1+7*t2+t3+1:3*t1+7*t2+2*t3)=P0.*y(3*t1+7*t2+t3+1:3*t1+7*t2+2*t3);
% y(3*t1+7*t2+2*t3+1:3*t1+7*t2+3*t3)=Ta0.*y(3*t1+7*t2+2*t3+1:3*t1+7*t2+3*t3);
% y(3*t1+7*t2+3*t3+1:3*t1+7*t2+4*t3)=Nev0.*y(3*t1+7*t2+3*t3+1:3*t1+7*t2+4*t3);
% y(3*t1+7*t2+4*t3+1:3*t1+7*t2+5*t3)=Npv0.*y(3*t1+7*t2+4*t3+1:3*t1+7*t2+5*t3);
% y(t+1)=600.*y(t+1);
% y(t+2)=6000.*y(t+2);
% 
%Initial values
y0=[T0 P0 Ta0 u0];

%Define options
opt=optimset('Display','iter','MaxFunEvals',50000,'MaxIter',100000);
%Call up fsolve
y=fsolve(@(y) condensermodell3(y,An,n,xn,Am,m,xm,Ao,o,xo,Tdew,y0,Nel0,Npl0,Nev0,Npv0),y,opt);

%Unpack y-vector
T(1:t1)=y(1:t1);
T(t1+1:t1+t2)=y(3*t1+1:3*t1+t2);
T(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+1:3*t1+7*t2+t3);
T=T';
P(1:t1)=y(t1+1:2*t1);
P(t1+1:t1+t2)=y(3*t1+t2+1:3*t1+2*t2);
P(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+t3+1:3*t1+7*t2+2*t3);
P=P';
Ta(1:t1)=y(2*t1+1:3*t1);
Ta(t1+1:t1+t2)=y(3*t1+2*t2+1:3*t1+3*t2);
Ta(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+2*t3+1:3*t1+7*t2+3*t3);
Ta=Ta';
Nev(1:t1)=Nev0.*ones(1,n+2);
Nev(t1+1:t1+t2)=y(3*t1+3*t2+1:3*t1+4*t2);
Nev(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+3*t3+1:3*t1+7*t2+4*t3);
Nev=Nev';
Npv(1:t1)=Npv0.*ones(1,n+2);
Npv(t1+1:t1+t2)=y(3*t1+4*t2+1:3*t1+5*t2);
Npv(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+4*t3+1:3*t1+7*t2+5*t3);
Npv=Npv';

Nev0v=Nev0*ones(1,m+2+n+2+o+2)';
Nel0v=Nel0*ones(1,m+2+n+2+o+2)';
Npv0v=Npv0*ones(1,m+2+n+2+o+2)';
Npl0v=Npl0*ones(1,m+2+n+2+0+2)';

%Calculate moles in condensate
Nel=Nev0v-Nev;
Npl=Npv0v-Npv;

nt(1:t1)=zeros(1,t1);
nt(t1+1:t1+t2)=y(3*t1+5*t2+1:3*t1+6*t2);
nt(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+5*t3+1:3*t1+7*t2+6*t3);
nt=nt';
ne(1:t1)=zeros(1,t1);
ne(t1+1:t1+t2)=y(3*t1+6*t2+1:3*t1+7*t2);
ne(t1+t2+1:t1+t2+t3)=y(3*t1+7*t2+6*t3+1:3*t1+7*t2+7*t3);
ne=ne';
np=nt-ne;
kp=y(t+3);

%Calculate molefractions
xE=Nel./(Nel+Npl);
xP=1-xE;
yE=Nev./(Nev+Npv);
yP=1-yE;

%Calculated areas
A1=y(t+1);
A2=y(t+2);
A3=y(t+4);

%Calculate plot points
xt(1:t1)=A1.*xn;
xt(t1+1:t1+t2)=A1+A2.*xm;
xt(t1+t2+1:t1+t2+t3)=A1+A2+A3.*xo;

%Save solution
save condensation_0206

%plot figures
figure(1)
plot(xt,T,xt,Ta)
title('Temperature')
legend('Vapour','Sea water')

figure(2)
plot(xt,Nev,xt,Npv,xt,Nel,xt,Npl)
title('Composition profile along condenser')
legend('Ethane vapour','Propane vapour','Ethane liquid','Propane liquid',-1);

figure(3)
plot(xt,P)
title('Pressure')