%This function is based on the code written by \cite{Nasri09}, and has only
%been modified to fit data for ethane and propane together with setting the
%pressure

function f=flash(x)
global z
phi=0;
% critical temperature and pressure and acentric factor
% for Ethane and Propane, obtained form \cite{Matschke62}
Pc=[48.72 42.48];
Tc=[305.32 369.83];
w=[0.099 0.152];
% pressure is set equal to 20 bars
P=20;
% reduced temperature and pressure
Tre=x(5)./Tc;
Pre=P./Pc;
% m, a, Ai, Bi, Aij, A, B for the PR EOS
m=0.37464 + 1.54226.*w-0.26992.*w.^2; 
a=(1+m.*(1-Tre.^0.5)).^2;
Ap=0.45724.*a.*Pre./Tre.^2;
Bp=0.07780.*Pre./Tre;

for i=1:2
    for j=1:2
        Ab(i,j)=(Ap(i)*Ap(j))^0.5;
    end
end
Av=0;
for i=1:2
    for j=1:2
        Av=Av+x(i+2)*x(j+2)*Ab(i,j);
    end
end
Bv=0;
for i=1:2
    Bv=Bv+x(i+2)*Bp(i);
end
Bl=0;
for i=1:2
    Bl=Bl+x(i)*Bp(i);
end
Al=0;
for i=1:2
    for j=1:2
        Al=Al+x(i)*x(j)*Ab(i,j);
    end
end
Alsum=[0 0];
for i=1:2
    for j=1:2
        Alsum(i)=Alsum(i)+x(j)*Ab(i,j);
    end
end
Avsum=[0 0];
for i=1:2
    for j=1:2
        Avsum(i)=Avsum(i)+x(j+2)*Ab(i,j);
    end
end

% liquid and gas phase compressibility factors
Zv=max(roots([1 -1+Bv Av-3*Bv^2-2*Bv -Av*Bv+Bv^2+Bv^3])); 
Zl=min(roots([1 -1+Bl Al-3*Bl^2-2*Bl -Al*Bl+Bl^2+Bl^3]));
% vapor and liquid phase fugacity coefficients 
phiv=exp((Zv-1).*Bp/Bv-log(Zv-Bv)...
-Av/(2*sqrt(2)*Bv)*log((Zv+(1+sqrt(2))*Bv)/...
(Zv+(1-sqrt(2))*Bv)).*(2.*Avsum./Av-Bp./Bv));
phil=exp((Zl-1).*Bp/Bl-log(Zl-Bl)...
-Al/(2*sqrt(2)*Bl)*log((Zl+(1+sqrt(2))*Bl)/...
(Zl+(1-sqrt(2))*Bl)).*(2.*Alsum./Al-Bp./Bl));
% equilibrium constant
K=phil./phiv;
% the system of five algebraic equations
for i=1:2
    f(i)=x(i+2)-K(i)*x(i);
end
for i=1:2
    f(i+2)=x(i)-z(i)/(1+phi*(K(i)-1));
end
f(5)=0;
for i=1:2
    f(5)=f(5)+z(i)*(K(i)-1)/(1+phi*(K(i)-1));
end

