%This function calculates the heatcapacity of the condensate based on
%\cite{Perry08}
%Input:
%   T temperature
%   Nel moles ethane in condensate
%   Npl moles propane in condensate
%Output:
%   Cp heatcapacity %J/kmol,K


function Cp=heatcapacitycond(T,Nel,Npl)

%Calculate molefractions
xE=Nel./(Nel+Npl);
xP=1-xE;

%Critical temperatures\citep{Matschke62}
Tce=305.32 ;
Tcp=369.83;

%Calculate te and tp
te=1-T./Tce;
tp=1-T./Tcp;

%Calculate individual heatcapacities
cpetl=44.009^2./te+89718-2*44.009*918.77.*te+44.009*1886.*te.^2-...
    918.77^2.*te.^3./3+918.77*1886.*te.^4./2-1886^2.*te.^5./5;
cpprl=62.983^2./tp+113630-2*62.983*633.21.*tp+62.983*873.46.*tp.^2-...
    633.21^2.*tp.^3./3+633.21*873.46.*tp.^4./2-873.46^2.*tp.^5./5;

%Calculate total heatcapacity
Cp=xE.*cpetl+xP.*cpprl;