%This function calculates the heat of condensation for the different
%temperatures based on \cite{Perry08}
%Input:
%   T temperature
%   comp indicates which component is used
%Output:
%   hcond heat of condensation


function hcond=heatofcond(T,comp)

%Critical temperatures from \cite{Matsche62}
Tce=305.32 ;
Tcp=369.83;

%Calculate reduced temperatures
TrE=T./Tce;
TrP=T./Tcp;

%Parameters for Ethane 
C1E=2.1091E7;
C2E=0.60646;
C3E=-0.55492;
C4E=0.32799;

%Parameters for Propane
C1P=2.92091E7;
C2P=0.78237;
C3P=-0.77319;
C4P=0.39246;

%Calculate heat of condensation
%As it is the heat of vapourisation that is used in the equations, the
%minus sign is also used in the condensermodels
if comp==1
hcond=-(C1E.*(1-TrE).^(C2E+C3E.*TrE+C4E.*TrE.^2)); %J/kmol ethane 
else
hcond=-(C1P.*(1-TrP).^(C2P+C3P.*TrP+C4P.*TrP.^2)); %J/kmol propane 
end