%This function calculates the mass transfer coefficient

function betaEP=masstransfer2(T,P,hg,Nev,Npv)

%Input:
%   Nev moles of ethane in vapour [kmol/s]
%   Npv moles of propane in vapour [kmol/s]
%   hg  vapour heat transfer coefficient [W/(m2,K)]
%   P   pressure [Pa]
%   T   temperature [K]
%Output:
%   betaEP mass transfer coefficient [kmol/(s,m2)]

%Calculate heatcapacity of vapour
Cpg=heatcapacity(T,Nev,Npv);

Meth=30.1; % molar weigth [kg/kmol]
Mprop=44.1; % molar weigth [kg/kmol]
R=8.314;    %Universal gas constant [kJ/(kmol K)]

%Calculate conductivity of vapour
 kg1=conductivity(T,0);    %W/mK

%Calculate pressure in bar
P1=P*9.869E-6;

%Calculat diffusivity coefficient according to Fullers method
D=1E-7*T.^(1.75).*(1/Meth+1/Mprop)^(0.5)./(P1.*((44.88)^(1/3)+(65.34)^(1/3)));

%Calculate consentration based on ideal gas law
c1=P./(R.*T*1000);   %[kmol/m3]

 %Calculate mass transfer coefficent according to \cite{Sajjan04}
 betaEP=hg./(Cpg).*(c1.*D.*Cpg./kg1).^(2/3); %[kmol/(s,m2)]