%This function calculates the equilibrium composition at 20 bars
%Input:
%   Nel moles ethane in condensate
%   Npl moles propane in condensate
%   P pressure [Pa]
%Output:
%   yet interface molefraction ethane in vapour

function [yet]= yequilibrium(Nel,Npl,P)

%Calculate molefraction ethane of condensate
xE=Nel./(Nel+Npl);

%Load correct equilibriumdata based on pressure
if P<2.01e+6
load equilibriumdata_P_20;
elseif P<2.02e+6
    load equilibriumdata_P_201;
elseif P<2.03e+6
    load equilibriumdata_P_202;
elseif P<2.04e+6
    load equilibriumdata_P_203;
elseif P<2.05e+6
    load equilibriumdata_P_204;
elseif P<2.06e+6
    load equilibriumdata_P_205;
elseif P<2.07e+6
    load equilibriumdata_P_206;
elseif P<2.08e+6
    load equilibriumdata_P_207;
elseif P<2.09e+6
    load equilibriumdata_P_208;
elseif P<2.1e+6
    load equilibriumdata_P_209;
else
    load equilibriumdata_P_21;
end
    

%Interpolate to find correct interface molefraction of ethane in vapour
l1=xE+0.1;
l2=xE-0.1;

j=find(xeti<l1 & xeti>l2);

[m n]=size(j);


if n==0
    l1=xE+0.2;
    l2=xE-0.2;
    
    j=find(xeti<l1 & xeti>l2);
    
    [m n]=size(j);
    
    if n==0
        l1=xE+0.3;
        l2=xE-0.3;
    
        j=find(xeti<l1 & xeti>l2);
        
        [m n]=size(j);
        
         if n==0
            l1=xE+0.4;
            l2=xE-0.4;
    
            j=find(xeti<l1 & xeti>l2);
            
            [m n]=size(j);
            
            if n==0
                l1=xE+0.5;
                l2=xE-0.5;
    
                j=find(xeti<l1 & xeti>l2);
            
                [m n]=size(j);
                if n==1

                    yet=yeti(j);
                else

                    yetinter=yeti(j);
                    xeinter=xeti(j);

                    yet=(xE-xeinter(2))*(yetinter(2)-yetinter(1))/...
                        (xeinter(2)-xeinter(1))+yetinter(1);
                end
            elseif n==1
                
                    yet=yeti(j);
            else

                    yetinter=yeti(j);
                    xeinter=xeti(j);

                    yet=(xE-xeinter(2))*(yetinter(2)-yetinter(1))/...
                        (xeinter(2)-xeinter(1))+yetinter(1);
            end
         
         elseif n==1

                    yet=yeti(j);
         else

                    yetinter=yeti(j);
                    xeinter=xeti(j);

                    yet=(xE-xeinter(2))*(yetinter(2)-yetinter(1))/...
                        (xeinter(2)-xeinter(1))+yetinter(1);
         end
         
    elseif n==1
                    yet=yeti(j);
    else

                    yetinter=yeti(j);
                    xeinter=xeti(j);

                    yet=(xE-xeinter(2))*(yetinter(2)-yetinter(1))/...
                        (xeinter(2)-xeinter(1))+yetinter(1);
    end

elseif n==1

                    yet=yeti(j);
else

                    yetinter=yeti(j);
                    xeinter=xeti(j);

                    yet=(xE-xeinter(2))*(yetinter(2)-yetinter(1))/...
                        (xeinter(2)-xeinter(1))+yetinter(1);
end
    